package com.lqkj.link.module.zone.repository;

import com.lqkj.link.module.zone.domain.ModelInfo;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface ModelInfoRepository extends JpaRepository<ModelInfo, Integer> {

    @Query(nativeQuery = true,
        value = "select count(*) from model_info where category_id = :categoryId"
    )
    Integer countWithCategory(@Param("categoryId") Integer categoryId);

    @Query(nativeQuery = true,
        value = "select mi.* from model_info mi " +
                "left join model_category mc on mi.category_id = mc.category_id " +
                "left join user_info ui on mc.user_id = ui.user_id " +
                "where mc.user_id is null or ui.user_code = :userCode order by mi.order_id"
    )
    List<ModelInfo> listWitUserCode(@Param("userCode") String userCode);

    @Query("select t from ModelInfo t where t.categoryId = :categoryId")
    List<ModelInfo> listWithCategory(@Param("categoryId") Integer categoryId);

    @Modifying
    @Query(nativeQuery = true,
        value = "delete from model_info where category_id = :categoryId"
    )
    void deleteWithCategory(@Param("categoryId") Integer categoryId);

    @Modifying
    @Query(nativeQuery = true,
        value = "delete from model_info where template_id in :templateIds"
    )
    void deleteAllByTemplateIds(@Param("templateIds") List<Integer> templateIds);

}
